@@ -1,5 +1,5 @@
 package JSON::Karabiner ;
-$JSON::Karabiner::VERSION = '0.009';
+$JSON::Karabiner::VERSION = '0.010';
 use strict;
 use warnings;
 use JSON;
@@ -30,10 +30,10 @@ sub new {
     _rule_obj => '',
   };
   if (!-d $self->{_mod_file_dir}) {
-    if ($opts->{_mod_file_dir}) {
+    if ($opts->{mod_file_dir}) {
       croak "The directory you attempted to set with the 'mod_file_dir' option does not exist.\n\n";
     } else {
-      croak "The default directory for storing complex modifications does not exist. Do you have Karbiner-Elements installed? Is it installed with a non-standard configuration? Try setting the location of the directory manually with the 'mod_file_dir' option. Consult this module's documentation for more information with using the 'perldoc JSON::Karabiner' command in the terminal.\n\n" unless $ENV{TEST_HARNESS};
+      croak "The default directory for storing complex modifications does not exist. Do you have Karbiner-Elements installed? Is it installed with a non-standard configuration? Try setting the location of the directory manually with the 'mod_file_dir' option. Consult this module's documentation for more information with using the 'perldoc JSON::Karabiner' command in the terminal.\n\n" unless $ENV{HARNESS_ACTIVE};
     }
   }
   bless $self, $class;
@@ -425,7 +425,7 @@ modules|https://www.cpan.org/modules/INSTALL.html> for more information.
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 Development Status
 
